==> haskell-mysql-0.2.1-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mysql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mysql
version:              0.2.1
visibility:           public
id:                   mysql-0.2.1-EHzlu5ViOh77MG2sbZblsU
key:                  mysql-0.2.1-EHzlu5ViOh77MG2sbZblsU
license:              BSD-3-Clause
copyright:
    Copyright 2011 MailRank, Inc.
    Copyright 2013 Bryan O'\''Sullivan <bos@serpentine.com>

maintainer:           Paul Rouse <pyr@doynton.org>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/paul-rouse/mysql
synopsis:             A low-level MySQL client library.
description:
    A low-level client library for the MySQL database, implemented as
    bindings to the C @mysqlclient@ API.

    /Important licensing note/: This library is BSD-licensed under the
    terms of the MySQL FOSS License Exception
    <http://www.mysql.com/about/legal/licensing/foss-exception/>.

    Since this library links against the GPL-licensed @mysqlclient@
    library, a non-open-source application that uses it /may/ be
    subject to the terms of the GPL.

category:             Database
abi:                  8e4fd01b08fc94337a785ab6aa956bb7
exposed:              True
exposed-modules:
    Database.MySQL.Base Database.MySQL.Base.C Database.MySQL.Base.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/mysql-0.2.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/mysql-0.2.1 /usr/lib/
dynamic-library-dirs: /usr/lib /usr/lib/
data-dir:             /usr/share/haskell-mysql
hs-libraries:         HSmysql-0.2.1-EHzlu5ViOh77MG2sbZblsU
extra-libraries:      dl m ssl crypto mariadb
include-dirs:         /usr/include/mysql /usr/include/mysql/mysql
depends:              base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
haddock-interfaces:   /usr/share/doc/haskell-mysql/html/mysql.haddock
haddock-html:         /usr/share/doc/haskell-mysql/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mysql-0.2.1-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mysql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mysql
version:              0.2.1
visibility:           public
id:                   mysql-0.2.1-FDf8URdGQsc5dtlrdup32a
key:                  mysql-0.2.1-FDf8URdGQsc5dtlrdup32a
license:              BSD-3-Clause
copyright:
    Copyright 2011 MailRank, Inc.
    Copyright 2013 Bryan O'\''Sullivan <bos@serpentine.com>

maintainer:           Paul Rouse <pyr@doynton.org>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/paul-rouse/mysql
synopsis:             A low-level MySQL client library.
description:
    A low-level client library for the MySQL database, implemented as
    bindings to the C @mysqlclient@ API.

    /Important licensing note/: This library is BSD-licensed under the
    terms of the MySQL FOSS License Exception
    <http://www.mysql.com/about/legal/licensing/foss-exception/>.

    Since this library links against the GPL-licensed @mysqlclient@
    library, a non-open-source application that uses it /may/ be
    subject to the terms of the GPL.

category:             Database
abi:                  61b198492ec288cfd1b9b6b68b77151a
exposed:              True
exposed-modules:
    Database.MySQL.Base Database.MySQL.Base.C Database.MySQL.Base.Types

import-dirs:          /usr/lib/ghc-9.0.2/site-local/mysql-0.2.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/mysql-0.2.1 /usr/lib/
dynamic-library-dirs: /usr/lib /usr/lib/
data-dir:             /usr/share/haskell-mysql
hs-libraries:         HSmysql-0.2.1-FDf8URdGQsc5dtlrdup32a
extra-libraries:      dl m ssl crypto mariadb
include-dirs:         /usr/include/mysql /usr/include/mysql/mysql
depends:              base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
haddock-interfaces:   /usr/share/doc/haskell-mysql/html/mysql.haddock
haddock-html:         /usr/share/doc/haskell-mysql/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
